// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef AKONADIMIME_VERSION_H
#define AKONADIMIME_VERSION_H

#define AKONADIMIME_VERSION_STRING "6.2.1"
#define AKONADIMIME_VERSION_MAJOR 6
#define AKONADIMIME_VERSION_MINOR 2
#define AKONADIMIME_VERSION_PATCH 1
#define AKONADIMIME_VERSION ((6<<16)|(2<<8)|(1))

#endif
